@@ -43,7 +43,7 @@
 #include <KUrlMimeData>
 #include <QUrl>
 
-#include <QtCore/QMimeData>
+#include <QMimeData>
 #include <QApplication>
 #include <QClipboard>
 #include <QDrag>
@@ -64,11 +64,10 @@ class KCalUtils::DndFactoryPrivate
 public:
     DndFactoryPrivate(const MemoryCalendar::Ptr &calendar)
         : mCalendar(calendar)
-    {}
+    {
+    }
 
-    Incidence::Ptr pasteIncidence(const Incidence::Ptr &incidence,
-                                  KDateTime newDateTime,
-                                  const QFlags<DndFactory::PasteFlag> &pasteOptions)
+    Incidence::Ptr pasteIncidence(const Incidence::Ptr &incidence, KDateTime newDateTime, QFlags<DndFactory::PasteFlag> pasteOptions)
     {
         Incidence::Ptr inc(incidence);
 
@@ -98,7 +97,6 @@ public:
                 } else {
                     event->setDtEnd(newDateTime.addSecs(durationInSeconds));
                 }
-
             } else if (inc->type() == Incidence::TypeTodo) {
                 Todo::Ptr aTodo = inc.staticCast<Todo>();
                 const bool pasteAtDtStart = (pasteOptions & DndFactory::FlagTodosPasteAtDtStart);
@@ -113,7 +111,6 @@ public:
                 } else {
                     aTodo->setDtDue(newDateTime);
                 }
-
             } else if (inc->type() == Incidence::TypeJournal) {
                 if (pasteOptions & DndFactory::FlagPasteAtOriginalTime) {
                     // Set date and preserve time and timezone stuff
@@ -200,14 +197,15 @@ MemoryCalendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData)
     return createDropCalendar(mimeData, d->mCalendar->timeSpec());
 }
 
-MemoryCalendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData,
-        const KDateTime::Spec &timeSpec)
+MemoryCalendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData, const KDateTime::Spec &timeSpec)
 {
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(timeSpec));
+    if (mimeData) {
+        MemoryCalendar::Ptr calendar(new MemoryCalendar(timeSpec));
 
-    if (ICalDrag::fromMimeData(mimeData, calendar) ||
-            VCalDrag::fromMimeData(mimeData, calendar)) {
-        return calendar;
+        if (ICalDrag::fromMimeData(mimeData, calendar)
+            || VCalDrag::fromMimeData(mimeData, calendar)) {
+            return calendar;
+        }
     }
 
     return MemoryCalendar::Ptr();
@@ -287,7 +285,8 @@ bool DndFactory::cutIncidences(const Incidence::List &incidences)
 {
     if (copyIncidences(incidences)) {
         Incidence::List::ConstIterator it;
-        for (it = incidences.constBegin(); it != incidences.constEnd(); ++it) {
+        const Incidence::List::ConstIterator end(incidences.constEnd());
+        for (it = incidences.constBegin(); it != end; ++it) {
             d->mCalendar->deleteIncidence(*it);
         }
         return true;
@@ -303,7 +302,8 @@ bool DndFactory::copyIncidences(const Incidence::List &incidences)
     MemoryCalendar::Ptr calendar(new MemoryCalendar(d->mCalendar->timeSpec()));
 
     Incidence::List::ConstIterator it;
-    for (it = incidences.constBegin(); it != incidences.constEnd(); ++it) {
+    const Incidence::List::ConstIterator end(incidences.constEnd());
+    for (it = incidences.constBegin(); it != end; ++it) {
         if (*it) {
             calendar->addIncidence(Incidence::Ptr((*it)->clone()));
         }
@@ -329,8 +329,7 @@ bool DndFactory::copyIncidence(const Incidence::Ptr &selectedInc)
     return copyIncidences(list);
 }
 
-Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime,
-        const QFlags<PasteFlag> &pasteOptions)
+Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime, QFlags<KCalUtils::DndFactory::PasteFlag> pasteOptions)
 {
     QClipboard *clipboard = QApplication::clipboard();
     Q_ASSERT(clipboard);
@@ -348,8 +347,9 @@ Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime,
 
     Incidence::List::ConstIterator it;
     const Incidence::List incidences = calendar->incidences();
+    Incidence::List::ConstIterator end(incidences.constEnd());
     for (it = incidences.constBegin();
-            it != incidences.constEnd(); ++it) {
+         it != end; ++it) {
         Incidence::Ptr incidence = d->pasteIncidence(*it, newDateTime, pasteOptions);
         if (incidence) {
             list.append(incidence);
@@ -358,7 +358,8 @@ Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime,
     }
 
     // update relations
-    for (it = list.constBegin(); it != list.constEnd(); ++it) {
+    end = list.constEnd();
+    for (it = list.constBegin(); it != end; ++it) {
         Incidence::Ptr incidence = *it;
         if (oldUidToNewInc.contains(incidence->relatedTo())) {
             Incidence::Ptr parentInc = oldUidToNewInc[incidence->relatedTo()];
@@ -372,8 +373,7 @@ Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime,
     return list;
 }
 
-Incidence::Ptr DndFactory::pasteIncidence(const KDateTime &newDateTime,
-        const QFlags<PasteFlag> &pasteOptions)
+Incidence::Ptr DndFactory::pasteIncidence(const KDateTime &newDateTime, QFlags<KCalUtils::DndFactory::PasteFlag> pasteOptions)
 {
     QClipboard *clipboard = QApplication::clipboard();
     MemoryCalendar::Ptr calendar(createDropCalendar(clipboard->mimeData()));
